@@ -22,13 +22,15 @@
 #ifndef _OPENOFFICE_ORG_CREATOR_H_
 #define _OPENOFFICE_ORG_CREATOR_H_
 
+#include <QObject>
 #include <kio/thumbcreator.h>
 
-class OOoCreator : public ThumbCreator
+class OOoCreator : public QObject, public ThumbCreator
 {
+    Q_OBJECT
 public:
     OOoCreator();
-    ~OOoCreator();
+    virtual ~OOoCreator();
     virtual bool create(const QString &path, int w, int h, QImage &img);
     virtual Flags flags() const;
 private:
